@@ -2,8 +2,4 @@ K 25
 svn:wc:ra_dav:version-url
 V 57
 /offlineimap/!svn/ver/130/offlineimap/head/offlineimap.py
-K 29
-svn:wc:ra_dav:version-url-rev
-V 3
-130
 END
