@@ -2,8 +2,4 @@ K 25
 svn:wc:ra_dav:version-url
 V 69
 /offlineimap/!svn/ver/131/offlineimap/head/offlineimap/folder/Base.py
-K 29
-svn:wc:ra_dav:version-url-rev
-V 3
-131
 END
