@@ -18,7 +18,7 @@
 
 from Base import BaseFolder
 from offlineimap import imaputil, imaplib
-import rfc822
+import rfc822, time
 from StringIO import StringIO
 from copy import copy
 
@@ -27,7 +27,7 @@ import __main__
 class IMAPFolder(BaseFolder):
     def __init__(self, imapserver, name, visiblename, accountname):
         self.name = imaputil.dequote(name)
-        self.root = imapserver.root
+        self.root = None # imapserver.root
         self.sep = imapserver.delim
         self.imapserver = imapserver
         self.messagelist = None
@@ -105,7 +105,16 @@ class IMAPFolder(BaseFolder):
 
             message = rfc822.Message(StringIO(content))
             mid = imapobj._quote(message.getheader('Message-Id'))
-            date = imaplib.Time2Internaldate(rfc822.parsedate(message.getheader('Date')))
+            datetuple = rfc822.parsedate(message.getheader('Date'))
+            # Will be None if missing or not in a valid format.
+            if datetuple == None:
+                datetuple = time.localtime()
+            try:
+                date = imaplib.Time2Internaldate(datetuple)
+            except ValueError:
+                # Argh, sometimes it's a valid format but year is 0102
+                # or something.  Argh.
+                date = imaplib.Time2Internaldate(time.localtime())
 
             if content.find("\r\n") == -1:  # Convert line endings if not already
                 content = content.replace("\n", "\r\n")
